@@ -1,6 +1,6 @@
 
 from .chat import Chat
-from letschatty.models.company.assets import TagPreview, FlowPreview, ChattyAssetPreview, ContactPoint, Sale, ChattyAIAgentPreview
+from letschatty.models.company.assets import TagPreview, FlowPreview, ContactPoint, Sale, ChattyAIAgentPreview, ProductPreview
 
 from letschatty.models.utils.types.serializer_type import SerializerType
 from pydantic import BaseModel
@@ -9,9 +9,9 @@ import json
 
 class ChatWithAssets(BaseModel):
     chat: Chat
-    products: List[ChattyAssetPreview]
-    tags: List[ChattyAssetPreview]
+    products: List[ProductPreview]
+    tags: List[TagPreview]
     sales: List[Sale]
     contact_points: List[ContactPoint]
     flows_links_states: List[FlowPreview]
-    chatty_ai_agent: Optional[ChattyAssetPreview]
+    chatty_ai_agent: Optional[ChattyAIAgentPreview]
