@@ -2,9 +2,12 @@ from pydantic import BaseModel, Field, model_validator
 from enum import StrEnum
 from datetime import datetime
 from typing import List, Optional
+
+from letschatty.models.utils import MessageType
 from .chain_of_thought_in_chat import ChainOfThoughtInChatRequest
 from ....messages.chatty_messages.base.message_draft import MessageDraft
 from letschatty.models.company.assets.ai_agents_v2.chatty_ai_agent import ChattyAIAgent
+from zoneinfo import ZoneInfo
 
 class SmartFollowUpDecisionAction(StrEnum):
     """Action for the smart follow up"""
@@ -27,14 +30,26 @@ class SmartFollowUpDecision(BaseModel):
             raise ValueError("Next call time is required")
         return self.next_call_time
 
+    def add_follow_up_strategy_info_to_chain_of_thought(self, follow_up_strategy_info: str):
+        self.chain_of_thought.chain_of_thought += f"\n\n La decisión fue: {self.action} \n{follow_up_strategy_info}"
+
     @model_validator(mode="after")
     def validate_messages(self):
         if self.action == SmartFollowUpDecisionAction.SEND or self.action == SmartFollowUpDecisionAction.SUGGEST:
             if self.messages is None or len(self.messages) == 0:
                 raise ValueError("Messages are required when action is send or suggest")
-        else:
+        elif self.action == SmartFollowUpDecisionAction.SKIP or self.action == SmartFollowUpDecisionAction.REMOVE:
             if self.messages is not None and len(self.messages) > 0:
                 raise ValueError("Messages are not allowed when action is skip or remove")
+        elif self.action == SmartFollowUpDecisionAction.ESCALATE:
+            #messages here are optional
+            pass
+        else:
+            raise ValueError(f"Invalid action: {self.action}")
+
+        #sometimes we get an empty message so we'll remove it
+        if self.messages:
+            self.messages = [message for message in self.messages if message.content.body != "" and message.type == MessageType.TEXT] #type: ignore
         return self
 
     def set_chain_of_thought_id(self, chain_of_thought_id: str):
