@@ -16,6 +16,11 @@ class FlowPreview(CompanyAssetModel):
     updated_at: datetime = Field(default_factory=lambda: datetime.now(tz=ZoneInfo("UTC")))
     company_id: StrObjectId = Field(alias="companyId")
 
+    @property
+    def is_smart_follow_up(self) -> bool:
+        """Check if the flow is a smart follow up"""
+        return self.title.lower() == "smart follow up"
+
     @classmethod
     def default_create_instance_method(cls, dict_data: Dict[str, Any]) -> 'FlowPreview':
 
