@@ -182,6 +182,15 @@ class User(CompanyAssetModel):
     def is_integration(self) -> bool:
         return self.user_type == UserType.INTEGRATION
 
+    @property
+    def is_super_agent(self) -> bool:
+        return UserRole.SUPER_AGENT in self.roles
+
+    @property
+    def can_see_all_agents_chats(self) -> bool:
+        return self.is_overviewer or self.is_super_admin or self.is_admin or self.is_super_agent
+
+
     @model_validator(mode="before")
     @classmethod
     def validate_email(cls, data: Any) -> Any:
