@@ -4,6 +4,8 @@ from typing import TYPE_CHECKING, Dict, List, Generic, TypeVar, Type, Optional,
 from bson.objectid import ObjectId
 from pymongo.collection import Collection
 from pymongo.database import Database
+
+from letschatty.models.chat.chat import Chat
 from ...models.base_models.chatty_asset_model import ChattyAssetModel, CompanyAssetModel, ChattyAssetPreview
 from ...models.utils.types import StrObjectId
 from ...models.utils.types.serializer_type import SerializerType
@@ -48,6 +50,7 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         logger.debug(f"Updating document with id {asset.id}")
         if not isinstance(asset, self.type):
             raise ValueError(f"Asset must be of type {self.type.__name__}")
+        asset.update_now()
         document = asset.model_dump_json(serializer=SerializerType.DATABASE)
         document.pop('_id', None)  # Still needed
         result = self.collection.update_one({"_id": ObjectId(asset.id)}, {"$set": document})
@@ -94,7 +97,7 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
     def delete(self, doc_id: str, deletion_type : DeletionType = DeletionType.LOGICAL) -> StrObjectId:
         logger.debug(f"Deleting document with id {doc_id} - deletion type: {deletion_type}")
         if deletion_type == DeletionType.LOGICAL:
-            result = self.collection.update_one({"_id": ObjectId(doc_id)}, {"$set": {"deleted_at": datetime.now(ZoneInfo("UTC"))}})
+            result = self.collection.update_one({"_id": ObjectId(doc_id)}, {"$set": {"deleted_at": datetime.now(ZoneInfo("UTC")), "updated_at": datetime.now(ZoneInfo("UTC"))}})
             if result.modified_count == 0:
                 raise NotFoundError(f"No document found with id {doc_id}")
             return doc_id
