@@ -3,5 +3,5 @@ from ...utils.types.message_types import MessageType
 from .schema import ChattyContentLocation
 
 class LocationMessage(Message):
-    type: str = MessageType.LOCATION.value
+    type: MessageType = MessageType.LOCATION
     content: ChattyContentLocation
\ No newline at end of file
