@@ -36,9 +36,9 @@ class FilledRecipientParameter(BaseModel):
             logger.error(f"Error in campaign creation: Missing parameter: {e} in recipient with phone number: {recipient_dict['phone_number']}")
             raise ValueError(f"Error in campaign creation: Missing parameter: {e} in recipient with phone number: {recipient_dict['phone_number']}")
 
-
 class FilledTemplateData(BaseModel):
     template_name: str
+    fast_answer_id: Optional[StrObjectId] = None
     area: Optional[Area]
     assign_to_agent: Optional[StrObjectId] = Field(default=None)
     phone_number: str | None = None
@@ -58,6 +58,12 @@ class FilledTemplateData(BaseModel):
     scheduled_messages_id : Optional[StrObjectId] = None
     continuous_conversation_id : Optional[StrObjectId] = None
 
+    @property
+    def recipient_name(self) -> str:
+        if self.new_contact_name:
+            return self.new_contact_name
+        return self.recipient_phone_number
+
     @property
     def recipient_phone_number(self) -> str:
         if not self.phone_number:
