@@ -244,9 +244,13 @@ class ChatService:
         """
         Update a workflow link for the chat.
         """
+        logger.debug(f"Updating workflow link for chat {chat.id} with workflow {workflow_id} and workflow link {workflow_link}")
         assigned_asset_to_remove = next(state for state in chat.flow_states if state.flow_id == workflow_id)
+        logger.debug(f"Assigned asset to remove: {assigned_asset_to_remove}")
         chat.flow_states.remove(assigned_asset_to_remove)
+        logger.debug(f"Chat flow states: {chat.flow_states}")
         bisect.insort(chat.flow_states, workflow_link)
+        logger.debug(f"Chat flow states after inserting the updated workflow link: {chat.flow_states}")
         execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
         return workflow_link
 
